@@ -31,12 +31,15 @@ class NotebookExecutor():
                              self.zeppelin_url, self.notebook_id))
 
             if r.status_code == 200:
-                print(r.json())
-                data = r.json()['body']
-                if all(paragraph['status'] in ['FINISHED', 'ERROR'] for paragraph in data):
-                    break
-                time.sleep(5)
-                continue
+                try:
+                    data = r.json()['body']
+                    if all(paragraph['status'] in ['FINISHED', 'ERROR'] for paragraph in data):
+                        break
+                    time.sleep(5)
+                    continue
+                except KeyError as e:
+                    print(e)
+                    print(r.json())
 
             elif r.status_code == 500:
                 print('Notebook is still busy executing. Checking again in 60 seconds...')
@@ -44,7 +47,7 @@ class NotebookExecutor():
                 continue
 
             else:
-                print('ERROR: Unexpected return code:{}'.format(r.status_code))
+                print('ERROR: Unexpected return code: {}'.format(r.status_code))
                 sys.exit(1)
             
 
